@@ -14,7 +14,12 @@ import unittest
 from io import BytesIO
 
 from botocore.awsrequest import AWSResponse
-from botocore.exceptions import AwsChunkedWrapperError, FlexibleChecksumError
+from botocore.compat import HAS_CRT
+from botocore.exceptions import (
+    AwsChunkedWrapperError,
+    FlexibleChecksumError,
+    MissingDependencyException,
+)
 from botocore.httpchecksum import (
     _CHECKSUM_CLS,
     AwsChunkedWrapper,
@@ -165,13 +170,29 @@ class TestHttpChecksumHandlers(unittest.TestCase):
         operation_model = self._make_operation_model(
             http_checksum={"requestAlgorithmMember": "Algorithm"},
         )
-        params = {"Algorithm": "crc32"}
+        params = {"Algorithm": "sha256"}
 
         with self.assertRaises(FlexibleChecksumError):
             resolve_request_checksum_algorithm(
                 request, operation_model, params, supported_algorithms=[]
             )
 
+    @unittest.skipIf(HAS_CRT, "Error only expected when CRT is not available")
+    def test_request_checksum_algorithm_model_no_crt_crc32c_unsupported(self):
+        request = self._build_request(b"")
+        operation_model = self._make_operation_model(
+            http_checksum={"requestAlgorithmMember": "Algorithm"},
+        )
+        params = {"Algorithm": "crc32c"}
+        with self.assertRaises(MissingDependencyException) as context:
+            resolve_request_checksum_algorithm(
+                request, operation_model, params
+            )
+            self.assertIn(
+                "Using CRC32C requires an additional dependency",
+                str(context.exception),
+            )
+
     def test_request_checksum_algorithm_model_legacy_md5(self):
         request = self._build_request(b"")
         operation_model = self._make_operation_model(required=True)
